<?php /* INCLUDES $Id: db_connect.class.php,v 1.1 2004/06/09 09:00:36 marco Exp $ */

/********************************************************************
 *   Autori:             Marco Colombo (marco@openit.it)
 *                       Valentina Portolan (valentina@openit.it)
 *                       Giuliano Natali Diaolin (diaolin@openit.it)
 *  Copyright:           Open It S.r.l.
 *                       Viale Dante, 78
 *                       38057 Pergine Valsugana (TN) ITALY
 *                       Tel: +39 0461 534800 Fax: +39 0461 538443
 *********************************************************************/

/**
* Generic functions based on library function (that is, non-db specific)
*
* @todo Encapsulate into a database object
*/

if (!defined('SM_PATH')) { define('SM_PATH','../'); }

class db_connect {
	var $db = null;
	var $error = null;

	function db_connect($db_type = NULL ){
	    global $addrbook_dsn;
	    if ($addrbook_dsn == "" || $addrbook_dsn == NULL){
		$this->error = 'FATAL ERROR: No Default Dbtype specified: Please check your configuration.';
	    }
	    if ($db_type == NULL) { 
        	preg_match('/^(.+):\/\//',$addrbook_dsn, $match);
		$db_type = $match[1]; 
	    }

	    //caricamento file db specifico
	    include_once("db_{$db_type}.class.php");
	    $this->db_type = $db_type;
	    //connessione a db
	    if ($db_type == "psql"){
		$this->db = & new db_psql();
	    } else if ($db_type == "mysql"){
		$this->db = & new db_mysql();
	    } else {
		$this->error = 'FATAL ERROR Login in the HERMES fax addressbook failed: '.$db_type.' not implemented.';
		return false;
	    }
	    return $this->db;
	}

	function echo_debug() {
	    return $this->db->logged_queries;
	}

	/**
	* This global function loads the first field of the first row returned by the query.
	*
	* @param string The SQL query
	* @return The value returned in the query or null if the query failed.
	*/
	function db_loadResult( $sql ) {
	    $cur = $this->db->db_query( $sql );
	    $cur or exit( $this->db->db_error() );
	    $ret = null;
	    if ($row = $this->db->db_fetch_row( $cur )) {
		$ret = $row[0];
	    }
	    $this->db->db_free_result( $cur );
	    return $ret;
	}

	/**
	* Document::db_loadColumn()
	*
	* { Description }
	*
	* @param [type] $maxrows
	*/
	function db_loadColumn( $sql, $maxrows=NULL ) {
	    if (!($cur = $this->db->db_query( $sql ))) {;
		$this->error = 	$this->db->db_error();
		return false;
	    }
	    $list = array();
	    $cnt = 0;
	    while ($row = $this->db->db_fetch_row( $cur )) {
		$list[] = $row[0];
		if( $maxrows && $maxrows == $cnt++ ) {
		    break;
		}
	    }
	    $this->db->db_free_result( $cur );
	    return $list;
	}

	/**
	* Document::db_loadList()
	*
	* { Description }
	*
	* @param [type] $maxrows
	*/
	function db_loadList( $sql, $maxrows=NULL ) {
	    if ($this->db->db_query( $sql ) == false) {;
		$this->error =  $this->db->db_error();
		return false;
	    }
	    $list = array();
	    $cnt = 0;
	    while ($hash = $this->db->db_fetch_assoc() ) {
		$list[] = $hash;
		if( $maxrows && $maxrows == $cnt++ ) { break; }
	    }
	    $this->db->db_free_result( $cur );
	    return $list;
	}

	/**
	* This global function return a result row as an associative array 
	*
	* @param string The SQL query
	* @param array An array for the result to be return in
	* @return <b>True</b> is the query was successful, <b>False</b> otherwise
	*/
	function db_loadHash( $sql ) {
	    $cur = $this->db->db_query( $sql );
	    $cur or exit( $this->db->db_error() );
	    $hash = $this->db->db_fetch_assoc( $cur );
	    $this->db->db_free_result( $cur );
	    if ($hash == false) {
		return false;
	    } else {
		return $hash;
	    }
	}

	/**
	* Document::db_insert()
	*
	* { Description }
	*
	* @param [type] $keyName
	* @param [type] $verbose
	*/
	function db_insert( $table, $userdata, $key, $hash, $plus) {
	    $table = $this->db_quotename($table);
    	    /* Create query */
    	    $query = "INSERT INTO $table (";
    	    $ql=array();
    	    $qv=array();
    	    foreach ($hash as $k => $v) {
        	if ($k == $key) { continue; }
        	array_push($ql,$this->db_quotename($k));
        	if ($userdata[$k]) {
		    $userdata[$k] = $this->db->db_escape( $userdata[$k] );
            	    array_push($qv,"'".$userdata[$k]."'");
        	} else {
            	    array_push($qv,"NULL");
        	}
    	    }
	    if (count($plus)) {
    		foreach ($plus as $k => $v) {
		    array_push($ql,$this->db_quotename($k));
        	    if ($plus[$k]) {
			$plus[$k] = $this->db->db_escape( $plus[$k] );
            		array_push($qv,"'".$plus[$k]."'");
        	    } else {
            		array_push($qv,"NULL");
        	    }
		}
	    }

    	    $query .= implode($ql,',').") VALUES (";
    	    $query .= implode($qv,',').")";
	    if (!$this->db->db_query( $query )) { return $query; }
	    return true;
	}

	/**
	* Document::db_delete()
	*
	* { Description }
	*
	*/
	function db_delete( $table, $keyName, $keyValue ) {
	    $table = $this->db_quotename($table);
	    $keyName = $this->db_quotename($keyName);
	    $keyValue = $this->db->db_escape( $keyValue );
	    $ret = $this->db->db_query( "DELETE FROM $table WHERE $keyName='$keyValue'" );
	    return $ret;
	}

	/**
	* Document::db_updateArray()
	*
	* { Description }
	*
	* @param [type] $verbose
	*/
	function db_update( $table, $userdata, $keyName, $value, $hash ) {
	    $table = $this->db_quotename($table);
    	    /* Create query */
    	    $query = "UPDATE $table SET ";
    	    $addstring = array();
    	    foreach ($hash as $key => $v) {
        	if ($key == $keyName) { continue; }
		$userdata[$key] = $this->db->db_escape( $userdata[$key] );
		$keyv = $this->db_quotename($key);
        	array_push($addstring,"$keyv = '$userdata[$key]'");
    	    }
    	    $query .= implode($addstring,',');
	    $keyName = $this->db_quotename($keyName);
    	    $query .= " WHERE $keyName=$value";

	    if (!$this->db->db_query( $query )) { return $query; }
	    return true;
	}

	/**
	* Document::db_updateArray()
	*
	* { Description }
	*
	* @param [type] $verbose
	*/
	function db_update_field( $table, $key, $value, $where ) {
	    $table = $this->db_quotename($table);
	    $key = $this->db_quotename($key);
    	    /* Create query */
    	    $query = "UPDATE $table SET $key = '$value' WHERE ";
	    $where_string = '';
	    $addstring = array();
    	    foreach ($where as $key => $v) {
		$v = $this->db->db_escape( $v );
		$key = $this->db_quotename($key);
        	array_push($addstring,"$key = '$v'");
    	    }
    	    $query .= implode($addstring,' AND ');

	    if (!$this->db->db_query( $query )) { return $query; }
	    return true;
	}

	/**
	*/
	function db_quotename( $string ) {
	    if ($this->db_type == "psql") {
		return "\"$string\"";
	    } else {
		return $string;
	    }
	}

}
?>