<?php

/********************************************************************
 *   Autori:             Marco Colombo (marco@openit.it)
 *                       Valentina Portolan (valentina@openit.it)
 *                       Giuliano Natali Diaolin (diaolin@openit.it)
 *  Copyright:           Open It S.r.l.
 *                       Viale Dante, 78
 *                       38057 Pergine Valsugana (TN) ITALY
 *                       Tel: +39 0461 534800 Fax: +39 0461 538443
 *********************************************************************/
/**
 * forms.php
 *
 * Copyright (c) 2004 The SquirrelMail Project Team
 * Licensed under the GNU GPL. For full terms see the file COPYING.
 *
 * Functions to build HTML forms in a safe and consistent manner.
 * All name, value attributes are htmlentitied.
 *
 * $Id: forms.php,v 1.3.2.4 2004/05/11 16:23:05 kink Exp $
 * @package squirrelmail
 */

if (!defined('SM_PATH')) { define('SM_PATH','../'); }

require_once(SM_PATH . 'functions/global.php');

/**
 * Helper function to create form fields, not to be called directly,
 * only by other functions below.
 */
function addInputField($type = null, $name = null, $value = null, $attributes = null) {
    return '<input type="'.$type.'"'.
        ($name  !== null ? ' name="'.codeHTML($name,1).'"'   : '').
        ($value !== null ? ' value="'.codeHTML($value,1).'"' : '').
        ' '.$attributes . " />\n";
}

/**
 * Password input field
 */
function addPwField($name = null, $value = null, $extra = null) {
    return addInputField('password', $name , $value, $extra);
}

/**
 * Form checkbox
 */
function addCheckBox($name = null, $checked = false, $value = null, $extra = null) {
    if ($checked) { $extra = 'checked="checked" '.$extra; }
    $extra .= ' override="1"';
    return addInputField('checkbox', $name, $value, $extra);
}

/**
 * Form radio box
 */
function addRadioBox($name = null, $checked = false, $value = null, $extra = null) {
    if ($checked) { $extra = 'checked="checked" '.$extra; }
    return addInputField('radio', $name, $value, $extra);
}

/**
 * A hidden form field.
 */
function addHidden($name = null, $value = null, $id = null) {
    $attr = "";
    if ($id) { $attr = ' id="'.$id.'"'; }
    return addInputField('hidden', $name, $value, $attr);
}

/**
 * An input textbox.
 */
function addInput($name = null, $value = null, $size = 0, $maxlength = 0, $attr = null) {
    if ($size) { $attr.= ' size="'.(int)$size.'"'; }
    if ($maxlength) { $attr.= ' maxlength="'.(int)$maxlength .'"'; }
    return addInputField('text', $name, $value, $attr);
}

/**
 * Function to create a selectlist from an array.
 * Usage:
 * name: html name attribute
 * values: array ( key => value )  ->     <option value="key">value
 * default: the key that will be selected
 * usekeys: use the keys of the array as option value or not
 */
function addSelect($name = null, $values = null, $default = null, $usekeys = false, $extra = null, $nocodehtml = 0) {
    $ret = '<select name="'.codeHTML($name).'" '.$extra.' >'."\n";
    foreach ($values as $k => $v) {
	$class = '';
        if(!$usekeys) $k = $v;
	if (!$nocodehtml) { $ret .= '<option value="'.codeHTML($k).'"'; }
	else { $ret .= '<option value="'.$k.'"'; }
	if (is_array($default) && in_array($default, $k)) { $ret .= ' selected="selected"'; }
	else if (!is_array($default) && $default == $k) { $ret .= ' selected="selected"'; }
	if (is_array($v)) { $class = ' class="'.$v['class'].'" '; $value = $v['value']; }
	else { $value = $v; }
	if (!$nocodehtml) { $ret .= $class.'>'.codeHTML($value).'</option>'."\n"; } 
	else { $ret .= $class.'>'.$value.'</option>'."\n"; }
    }
    $ret .= '</select>'."\n";
    return $ret;
}

/**
 * Form submission submit
 * Note the switched value/name parameters!
 */
function addSubmit($value = null, $name = null, $extra = null, $onclick = null, $form = null, $if = null, $nowait = null, $nosubmit = null) {
    $extra .= ' onclick=\'';
    if ($onclick) { $extra .= $onclick.' '; }
    if ($if) { $extra .= 'if ('.$if.') {'; }
    if (!$nowait) { 
	if (!$nosubmit) {
	    $extra .= 'this.disabled=1; this.value="'.jsspecialchars(_('Please wait...')).'"; document.'.$form.'.submit();';
	} else {
	    $extra .= 'this.disabled=1; this.value="'.jsspecialchars(_('Please wait...')).'";';
	}
    } else {
	if (!$nosubmit) {
	    $extra .= 'document.'.$form.'.submit();';
	}
    }
    if ($if) { $extra .= '} else { return false; }'; }
    $extra .= '\'';    
    return addInputField('submit', $name, jsspecialchars($value), $extra);
}

/**
 * Form submission button
 * Note the switched value/name parameters!
 */
function addButton($value = null, $name = null, $extra = null, $onclick = null, $form = null, $if = null, $nowait = null, $nosubmit = null) {
    $extra .= ' onclick=\'';
    if ($onclick && (!$nosubmit || $nosubmit != 2)) { $extra .= $onclick.' '; }
    if ($if) { $extra .= 'if ('.$if.') {'; }
    if (!$nowait) { 
	if (!$nosubmit) {
	    $extra .= 'this.disabled=1; this.value="'.jsspecialchars(_('Please wait...')).'"; document.'.$form.'.submit();';
	} else if ($nosubmit == 1) {
	    $extra .= 'this.disabled=1; this.value="'.jsspecialchars(_('Please wait...')).'";';
	} else if ($nosubmit == 2) {
	    $extra .= 'this.disabled=1; this.value="'.jsspecialchars(_('Please wait...')).'"; '.$onclick;
	}
    } else {
	if (!$nosubmit) {
	    $extra .= 'document.'.$form.'.submit();';
	} else if ($nosubmit == 2) {
	    $extra .= $onclick;
	}
    }
    if ($if) { $extra .= '} else { return false; }'; }
    $extra .= '\'';    
    return addInputField('button', $name, jsspecialchars($value), $extra);
}

/**
 * Form reset button, $value = caption
 */
function addReset($value = null) {
    return addInputField('reset', null, $value);
}

/**
 * Textarea form element.
 */
function addTextArea($name = null, $text = null, $cols = 40, $rows = 10, $attr = null, $nosanetize = 0) {
    if (!$nosanetize) { $text = codeHTML($text,1); }
    return '<textarea name="'.codeHTML($name).'" '.
        'rows="'.(int)$rows .'" cols="'.(int)$cols.'" '.
        $attr . '>'.$text ."</textarea>\n";
}

/**
 * Make a <form> start-tag.
 */
function addForm($action = null, $method = 'POST', $name = null, $enctype = null, $charset = null, $onload = null, $target = null) {
    if($name) { $name = ' name="'.$name.'"'; }
    if($enctype) { $enctype = ' enctype="'.$enctype.'"'; }
    if($charset) { $charset = ' accept-charset="'.codeHTML($charset).'"'; }
    if($onload) { $onload = ' onSubmit="'.$onload.'"'; }
    if($target) { $target = ' target="'.$target.'"'; }
    return '<form action="'.$action.'" method="'.$method.'"'.$enctype.$name.$charset.$target.$onload.">\n";
}

?>